package cn.alibaba.open.param;

import com.alibaba.ocean.rawsdk.client.APIId;
import com.alibaba.ocean.rawsdk.common.AbstractAPIRequest;

import java.util.*;
import java.math.BigDecimal;
import java.math.BigInteger;

public class CaigouApiProductAddProductParam extends AbstractAPIRequest<CaigouApiProductAddProductResult> {

    public CaigouApiProductAddProductParam() {
        super();
        oceanApiId = new APIId("cn.alibaba.open", "caigou.api.product.addProduct", 1);
    }

    private String productCode;

    /**
     * @return 产品编号，物料编码，代表产品在外部系统的主键
     */
    public String getProductCode() {
        return productCode;
    }

    /**
     * 设置产品编号，物料编码，代表产品在外部系统的主键     *
     * 参数示例：<pre>coop_prod_01</pre>     
     * 此参数必填
     */
    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    private String title;

    /**
     * @return 产品名
     */
    public String getTitle() {
        return title;
    }

    /**
     * 设置产品名     *
     * 参数示例：<pre>服装</pre>     
     * 此参数必填
     */
    public void setTitle(String title) {
        this.title = title;
    }

    private String unit;

    /**
     * @return 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 设置单位     *
     * 参数示例：<pre>件</pre>     
     * 此参数必填
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }

    private String remark;

    /**
     * @return 补充说明，可以为富文本。最多4000个字符
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 设置补充说明，可以为富文本。最多4000个字符     *
     * 参数示例：<pre>超级厚的大衣啊</pre>     
     * 此参数必填
     */
    public void setRemark(String remark) {
        this.remark = remark;
    }

    private String instruction;

    /**
     * @return 产品说明，副标题，最多200个字符
     */
    public String getInstruction() {
        return instruction;
    }

    /**
     * 设置产品说明，副标题，最多200个字符     *
     * 参数示例：<pre>黑色大衣，尺寸是标准欧码，今冬最新款，现在下单优惠10%。</pre>     
     * 此参数必填
     */
    public void setInstruction(String instruction) {
        this.instruction = instruction;
    }

    private List productAttributes;

    /**
     * @return 产品属性列表
     */
    public List getProductAttributes() {
        return productAttributes;
    }

    /**
     * 设置产品属性列表     *
     * 参数示例：<pre>[{"keyAttr":"false","name":"外置配件","unit":"件","values":["红色","黑色","绿色","蓝色"]},{"keyAttr":"false","name":"附属装备","unit":"个","values":["红色","黑色","绿色","蓝色"]}]</pre>     
     * 此参数必填
     */
    public void setProductAttributes(List productAttributes) {
        this.productAttributes = productAttributes;
    }

    private List picUrlList;

    /**
     * @return 产品图片，最多10张，先调用上传图片接口，获取到图片相对url
     */
    public List getPicUrlList() {
        return picUrlList;
    }

    /**
     * 设置产品图片，最多10张，先调用上传图片接口，获取到图片相对url     *
     * 参数示例：<pre>['img/product/15/02/60/15026073.jpg','img/product/15/02/60/15026073.jpg','img/product/15/02/60/15026073.jpg']</pre>     
     * 此参数必填
     */
    public void setPicUrlList(List picUrlList) {
        this.picUrlList = picUrlList;
    }

    private List attachmentList;

    /**
     * @return 产品附件，最多3个附件，先调用上传附件接口获取到附件id
     */
    public List getAttachmentList() {
        return attachmentList;
    }

    /**
     * 设置产品附件，最多3个附件，先调用上传附件接口获取到附件id     *
     * 参数示例：<pre>[1262298693,1262298693,1262298707]</pre>     
     * 此参数必填
     */
    public void setAttachmentList(List attachmentList) {
        this.attachmentList = attachmentList;
    }

    private Long referencePrice;

    /**
     * @return 产品参考价(单位是分)
     */
    public Long getReferencePrice() {
        return referencePrice;
    }

    /**
     * 设置产品参考价(单位是分)     *
     * 参数示例：<pre>152300</pre>     
     * 此参数必填
     */
    public void setReferencePrice(Long referencePrice) {
        this.referencePrice = referencePrice;
    }

    private Long userCategoryId;

    /**
     * @return 用户在1688的自定义类目id
     */
    public Long getUserCategoryId() {
        return userCategoryId;
    }

    /**
     * 设置用户在1688的自定义类目id     *
     * 参数示例：<pre></pre>     
     * 此参数必填
     */
    public void setUserCategoryId(Long userCategoryId) {
        this.userCategoryId = userCategoryId;
    }

    private Long userId;

    /**
     * @return 操作员在1688上的子帐号ID，如果接入商有子账号，则可以通过子账号来发布产品；不传则系统会自动取主账号的userId作为默认值
     */
    public Long getUserId() {
        return userId;
    }

    /**
     * 设置操作员在1688上的子帐号ID，如果接入商有子账号，则可以通过子账号来发布产品；不传则系统会自动取主账号的userId作为默认值     *
     * 参数示例：<pre></pre>     
     * 此参数必填
     */
    public void setUserId(Long userId) {
        this.userId = userId;
    }

}
